<?php
// core configuration
include_once "config/core.php";

// include classes
include_once 'config/database.php';

// get ID of the product to be edited
$id = isset($_GET['id']) ? $_GET['id'] : die('ERROR: missing ID.');

// set page title
$page_title = "Update Category";

// include page header HTML
include_once "layout_head.php";

// read category button
echo "<div class='overflow-hidden margin-bottom-1em'>";
	echo "<a href='read_categories.php' class='btn btn-primary pull-right'>";
		echo "<span class='glyphicon glyphicon-list'></span> Read Categories";
	echo "</a>";
echo "</div>";

// if the form was submitted
if($_POST){

	// set category property values
	$name=htmlspecialchars(strip_tags($_POST['name']));
	$description=htmlspecialchars(strip_tags($_POST['description']));

	if(empty($name)){
		echo "<div class='alert alert-danger'>Name cannot be empty.</div>";
	}

	else if(empty($description)){
		echo "<div class='alert alert-danger'>Description cannot be empty.</div>";
	}

	else{

		// update the category
		$query = "UPDATE categories
				SET name = :name, description = :description
				WHERE id = :id";

		// prepare query statement
		$stmt = $con->prepare($query);

		// bind values
		$stmt->bindParam(':name', $name);
		$stmt->bindParam(':description', $description);
		$stmt->bindParam(':id', $id);

		// execute the query
		if($stmt->execute()){

			echo "<div class=\"alert alert-success alert-dismissable\">";
				echo "<button type=\"button\" class=\"close\" data-dismiss=\"alert\" aria-hidden=\"true\">&times;</button>";
				echo "Category was updated.";
			echo "</div>";
		}

		// if unable to update the category, tell the user
		else{
			echo "<div class=\"alert alert-danger alert-dismissable\">";
				echo "<button type=\"button\" class=\"close\" data-dismiss=\"alert\" aria-hidden=\"true\">&times;</button>";
				echo "Unable to update category.";
			echo "</div>";
		}
	}
}


// read the details of category to be edited
// select single record query
$query = "SELECT name, description
		FROM categories
		WHERE id = ?
		LIMIT 0,1";

// prepare query statement
$stmt = $con->prepare( $query );

// bind selected record id
$stmt->bindParam(1, $id);

// execute the query
$stmt->execute();

// get record details
$row = $stmt->fetch(PDO::FETCH_ASSOC);

// assign values to object properties
$name = $row['name'];
$description = $row['description'];
?>

<!-- HTML form for updating a product -->
<form action='update_category.php?id=<?php echo $id; ?>' method='post'>

	<table class='table table-hover table-responsive table-bordered'>

		<tr>
			<td>Name</td>
			<td><input type='text' name='name' value='<?php echo $name; ?>' class='form-control' required></td>
		</tr>

		<tr>
			<td>Description</td>
			<td><textarea name='description' class='form-control'><?php echo $description; ?></textarea></td>
		</tr>

		<tr>
			<td></td>
			<td>
				<button type="submit" class="btn btn-primary">
					<span class='glyphicon glyphicon-edit'></span> Update
				</button>
			</td>
		</tr>

	</table>
</form>

<?php
// include page footer HTML
include_once "layout_foot.php";
?>
